<?php
/**
 * Adore Themes Customizer
 *
 * @package Current News
 *
 * Breaking News Section
 */

$wp_customize->add_section(
	'current_news_breaking_news_section',
	array(
		'title' => esc_html__( 'Breaking News Section', 'current-news' ),
		'panel' => 'current_news_frontpage_panel',
	)
);

// Breaking News section enable settings.
$wp_customize->add_setting(
	'current_news_breaking_news_section_enable',
	array(
		'default'           => false,
		'sanitize_callback' => 'current_news_sanitize_checkbox',
	)
);

$wp_customize->add_control(
	new Current_News_Toggle_Checkbox_Custom_control(
		$wp_customize,
		'current_news_breaking_news_section_enable',
		array(
			'label'    => esc_html__( 'Enable Breaking News Section', 'current-news' ),
			'type'     => 'checkbox',
			'settings' => 'current_news_breaking_news_section_enable',
			'section'  => 'current_news_breaking_news_section',
		)
	)
);

// Breaking News title settings.
$wp_customize->add_setting(
	'current_news_breaking_news_title',
	array(
		'default'           => __( 'Breaking News', 'current-news' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'current_news_breaking_news_title',
	array(
		'label'           => esc_html__( 'Title', 'current-news' ),
		'section'         => 'current_news_breaking_news_section',
		'active_callback' => 'current_news_if_breaking_news_enabled',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'current_news_breaking_news_title',
		array(
			'selector'            => '.news-ticker-section .theme-wrapper',
			'settings'            => 'current_news_breaking_news_title',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'current_news_breaking_news_title_text_partial',
		)
	);
}

// breaking_news content type settings.
$wp_customize->add_setting(
	'current_news_breaking_news_content_type',
	array(
		'default'           => 'post',
		'sanitize_callback' => 'current_news_sanitize_select',
	)
);

$wp_customize->add_control(
	'current_news_breaking_news_content_type',
	array(
		'label'           => esc_html__( 'Content type:', 'current-news' ),
		'description'     => esc_html__( 'Choose where you want to render the content from.', 'current-news' ),
		'section'         => 'current_news_breaking_news_section',
		'type'            => 'select',
		'active_callback' => 'current_news_if_breaking_news_enabled',
		'choices'         => array(
			'post' => esc_html__( 'Post', 'current-news' ),
			'page' => esc_html__( 'Page', 'current-news' ),
		),
	)
);

for ( $i = 1; $i <= 5; $i++ ) {
	// breaking_news post setting.
	$wp_customize->add_setting(
		'current_news_breaking_news_post_' . $i,
		array(
			'sanitize_callback' => 'current_news_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'current_news_breaking_news_post_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Post %d', 'current-news' ), $i ),
			'section'         => 'current_news_breaking_news_section',
			'type'            => 'select',
			'choices'         => current_news_get_post_choices(),
			'active_callback' => 'current_news_breaking_news_section_content_type_post_enabled',
		)
	);

	// breaking_news page setting.
	$wp_customize->add_setting(
		'current_news_breaking_news_page_' . $i,
		array(
			'default'           => 0,
			'sanitize_callback' => 'current_news_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'current_news_breaking_news_page_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Page %d', 'current-news' ), $i ),
			'section'         => 'current_news_breaking_news_section',
			'type'            => 'dropdown-pages',
			'choices'         => current_news_get_page_choices(),
			'active_callback' => 'current_news_breaking_news_section_content_type_page_enabled',
		)
	);
}

/*========================Active Callback==============================*/
function current_news_if_breaking_news_enabled( $control ) {
	return $control->manager->get_setting( 'current_news_breaking_news_section_enable' )->value();
}
function current_news_breaking_news_section_content_type_page_enabled( $control ) {
	$content_type = $control->manager->get_setting( 'current_news_breaking_news_content_type' )->value();
	return current_news_if_breaking_news_enabled( $control ) && ( 'page' === $content_type );
}
function current_news_breaking_news_section_content_type_post_enabled( $control ) {
	$content_type = $control->manager->get_setting( 'current_news_breaking_news_content_type' )->value();
	return current_news_if_breaking_news_enabled( $control ) && ( 'post' === $content_type );
}

/*========================Partial Refresh==============================*/
if ( ! function_exists( 'current_news_breaking_news_title_text_partial' ) ) :
	// Title.
	function current_news_breaking_news_title_text_partial() {
		return esc_html( get_theme_mod( 'current_news_breaking_news_title' ) );
	}
endif;
